==> python-slimta-0.3.8.tar.gz: python-slimta-0.3.8/slimta/relay/blackhole.py <==
# Copyright (c) 2013 Ian C. Good
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

"""This module contains a simple |Relay| class that blackholes messages, usually
most useful for testing.

"""

from __future__ import absolute_import

import uuid

from slimta.smtp.reply import Reply
from . import Relay

__all__ = ['BlackholeRelay']


class BlackholeRelay(Relay):
    """Implements a |Relay| that simply blackholes messages. Relay policies may
    be added with :meth:`~slimta.relay.Relay.add_policy`, but they will never be
    executed or applied for messages handled by this class.
    
    """

    def __init__(self):
        super(BlackholeRelay, self).__init__()

    def _attempt(self, envelope, attempts):
        return self.attempt(envelope, attempts)

    def attempt(self, envelope, attempts):
        """Overrides the |Relay| :meth:`~slimta.relay.Relay.attempt` method to
        silently discard attempted messages. The |Queue| will see the attempt as
        a successful delivery.

        :param envelope: |Envelope| to attempt delivery for.
        :param attempts: Number of times the envelope has attempted delivery.

        """
        msg = '2.0.0 Message Delivered; {0!s}'.format(uuid.uuid4())
        return Reply('250', msg)


# vim:et:fdm=marker:sts=4:sw=4:ts=4

==> python-slimta-0.3.12.tar.gz: python-slimta-0.3.12/slimta/relay/blackhole.py <==
# Copyright (c) 2013 Ian C. Good
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
#

"""This module contains a simple |Relay| class that blackholes messages,
usually most useful for testing.

"""

from __future__ import absolute_import

import uuid

from slimta.smtp.reply import Reply
from . import Relay

__all__ = ['BlackholeRelay']


class BlackholeRelay(Relay):
    """Implements a |Relay| that simply blackholes messages. Relay policies may
    be added with :meth:`~slimta.relay.Relay.add_policy`, but they will never
    be executed or applied for messages handled by this class.

    """

    def __init__(self):
        super(BlackholeRelay, self).__init__()

    def _attempt(self, envelope, attempts):
        return self.attempt(envelope, attempts)

    def attempt(self, envelope, attempts):
        """Overrides the |Relay| :meth:`~slimta.relay.Relay.attempt` method to
        silently discard attempted messages. The |Queue| will see the attempt
        as a successful delivery.

        :param envelope: |Envelope| to attempt delivery for.
        :param attempts: Number of times the envelope has attempted delivery.

        """
        msg = '2.0.0 Message Delivered; {0!s}'.format(uuid.uuid4())
        return Reply('250', msg)


# vim:et:fdm=marker:sts=4:sw=4:ts=4
